:orphan:


################################
Matplotlib Enhancement Proposals
################################

Matplotlib Enhancement Proposals (MEP), inspired by cpython's `PEP's
<https://www.python.org/dev/peps/>`__ but less formal, are design
documents for large or controversial changes to Matplotilb.  These
documents should provide a discussion of both why and how the changes
should be made.

To create a new MEP open a pull request (PR) adding a file based on
:ref:`the template <MEP-template>` to this the MEP directory.  For the
initial PR only a rough description is required and it should be
merged quickly.  Further detailed discussion can happen in follow on
PRs.
